@@ -2,12 +2,18 @@ from .climate import ClimateField
 from .proxy import ProxyRecord, ProxyDatabase
 from .reconjob import ReconJob
 from .reconres import ReconRes
-from . import graphem, utils
+from . import utils
+
 try:
     from . import ml
 except:
     pass
 
+try:
+    import graphem
+except:
+    pass
+
 from .visual import (
     set_style,
     showfig,
